.. include:: ../README.md
   :parser: myst_parser.sphinx_

Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   Overview <self>
   install
   usage
   cli
   args
   api/api

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
